/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.apps.component.cfw;

import java.util.List;
import java.util.ArrayList;
import java.util.Iterator;

import gov.anl.aps.irmis.persistence.pv.Record;

/**
 * Application data model for IRMIS PV Viewer. Stores graph of current set of ioc's
 * and related data. Stores record search result set, and the individual record
 * of interest. A list of listeners interested in this data is maintained, and
 * notified as requested.
 */
public class ComponentModel {

    // list of others interested in changes to the data model
    private List componentModelListenersList = new ArrayList();

	/**
	 * Do nothing constructor
	 */
	public ComponentModel() {
	}

    public void addComponentModelListener(ComponentModelListener l) {
        componentModelListenersList.add(l);
    }

    public void notifyComponentModelListeners() {
        notifyComponentModelListeners(null);
    }

    /**
     * Notify registered listeners of the given <code>ComponentModelEvent</code>.
     *
     * @param modelEvent encapsulates one of several possible events
     */
    public void notifyComponentModelListeners(ComponentModelEvent modelEvent) {
        Iterator it = componentModelListenersList.iterator();
        while (it.hasNext()) {
            ComponentModelListener l = (ComponentModelListener)it.next();
            l.modified(modelEvent);
        }
    }
}
