/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.apps.irmis.cfw;

import gov.anl.aps.irmis.login.LoginUtil;
import gov.anl.aps.irmis.apps.pv.cfw.PVDocument;
import gov.anl.aps.irmis.apps.component.cfw.ComponentDocument;
import gov.anl.aps.irmis.apps.ioc.cfw.IOCDocument;

import java.awt.event.ActionEvent;
import java.net.MalformedURLException;
import java.net.URL;

import javax.swing.Action;
import javax.swing.AbstractAction;
import javax.swing.JFrame;

//import java.util.logging; JDK 1.5 package ?

import gov.sns.application.*;

/**
 * Entry point for IRMIS application. Defines basic information
 * for XAL framework and kicks off actual application.
 */
public class Main extends DesktopApplicationAdaptor {

    // custom actions for login/logout menu add-ons
	private Action _loginAction;
	private Action _logoutAction;

    /**
     * Returns the text file suffixes of files this application can open.
     * @return Suffixes of readable files
     */
    public String[] readableDocumentTypes() {
        return new String[] {};
    }
    
    
    /**
     * Returns the text file suffixes of files this application can write.
     * @return Suffixes of writable files
     */
    public String[] writableDocumentTypes() {
        return new String[] {};
    }
    
    
    /**
     * Implement this method to return an instance of my custom document.
     * PVDocument is the initial document in this multi-document application.
     *
     * @return An instance of my custom document.
     */
    public XalInternalDocument newEmptyDocument() {
        return new PVDocument();
    }

    /**
     * Implement this method to return an instance of the appropriate 
     * document based on the string argument.
     *
     * @param type string name for desired document type (comes from new menu)
     * @return An instance of my custom document.
     */
    public XalInternalDocument newEmptyDocument(String type) {
        if (type.equals("idtpv")) {
            return new PVDocument();
        } else if (type.equals("idtioc")) {
            return new IOCDocument();
        } else {
            return new PVDocument();
        }
    }
    
    
    /**
     * Implement this method to return an instance of my custom document
     * corresponding to the specified URL. 
     * @param url The URL of the file to open.
     * @return An instance of my custom document.
     */
    public XalInternalDocument newDocument(final URL url) {
        return new PVDocument(url);
    }
    
    
    // --------- Global application management ---------------------------------
    
    
    /**
     * Specifies the name of my application.
     * @return Name of my application.
     */
    public String applicationName() {
        return "IRMIS (not logged in)";
    }
    
    
    
    // --------- Application events --------------------------------------------
    
    /** 
     * Capture the application launched event and print it.  This is an optional
     * hook that can be used to do something useful at the end of the application launch.
     */
    public void applicationFinishedLaunching() {
        System.out.println("IRMIS running...");
        //Logger.getLogger("global").log(Level.INFO, "IRMIS running...");
    }

    /**
     * Register some new menu actions. See menudef.properties to see what actual
     * menu these are used in.
     */
    protected void customizeCommands(Commander commander) {
        _loginAction = new AbstractAction("login") {
                public void actionPerformed(ActionEvent event) {
                    // supply our desktop frame so login knows where to pop up login dialog
                    JFrame appFrame = ((DesktopApplication)Application.getApp()).getDesktopFrame();
                    if (LoginUtil.login(appFrame)) {
                        appFrame.setTitle("IRMIS (logged in as " + LoginUtil.getUsername() + ")");
                    } else {
                        appFrame.setTitle("IRMIS (login failed)");
                    }
                }
            };
        commander.registerAction(_loginAction);

        _logoutAction = new AbstractAction("logout") {
                public void actionPerformed(ActionEvent event) {
                    LoginUtil.logout();
                    JFrame appFrame = ((DesktopApplication)Application.getApp()).getDesktopFrame();
                    appFrame.setTitle("IRMIS (not logged in)");
                }
            };
        commander.registerAction(_logoutAction);

    }
    
    
    /**
     * Constructor
     */
    public Main() {
    }
    
    
    /**
     * Application entry point. Begin with <code>Application.launch()</code> 
     * to start the initial PVDocument. Then bring up the other documents
     * of this multi-document application ComponentDocument, CableDocument, etc...
     */
	public static void main(String[] args) {
        try {
            System.out.println("Starting IRMIS...");
            //Logger.getLogger("global").log(Level.INFO,"Starting IRMIS...");

			Application.launch( new Main());
            DesktopApplication app = (DesktopApplication)Application.getApp();
            /*
            String[] choices = {"PV Viewer","IOC Viewer"};
            String s = AppSelectDialog.showDialog(app.getDesktopFrame(),
                                                  null,
                                                  "Select Initial Application:",
                                                  "Application Chooser",
                                                  choices,
                                                  "PV Viewer","PV Viewer");
            if (s.equals("PV Viewer"))
                app.produceDocument(new PVDocument());
            else if (s.equals("IOC Viewer"))
                app.produceDocument(new IOCDocument());
            */
            app.produceDocument(new PVDocument());
            //app.produceDocument(new IOCDocument());


        }
        catch(Exception exception) {
            //Logger.getLogger("global").log(Level.SEVERE, "Error starting app.", exception);
            System.err.println( exception.getMessage() );
            exception.printStackTrace();
			Application.displayApplicationError("Launch Exception", "Launch Exception", exception);
			System.exit(-1);
        }
    }
}
