/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.persistence.login;

import gov.anl.aps.irmis.persistence.HashCodeUtil;
import java.io.Serializable;
import java.util.Date;

/**
 * IRMIS business object that represents a single role name.
 * This class is mapped via hibernate almost one-to-one with IRMIS role_name table.
 */
public class RoleName implements Serializable {

    private Long id;
    private String roleName;

    /**
     * Constructor
     */
    public RoleName() {
    }

    /**
     * Get primary key.
     */
    public Long getId() {
        return this.id;
    }

    /**
     * Primary key. Not typically set explicitly by application code.
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * Get the role name.
     */
    public String getRoleName() {
        return this.roleName;
    }
    /**
     * Set the role name.
     */    
    public void setRoleName(String roleName) {
        this.roleName = roleName;
    }

    public String toString() {
        return getId().toString() + ":" + getRoleName();
    }

    /**
     * Custom equals which compares "business key" equality.
     */
    public boolean equals(Object other) {
        if (this==other) return true;
        if ( !(other instanceof RoleName) ) return false;
        final RoleName castOther = (RoleName) other;
        return this.getRoleName().equals(castOther.getRoleName());
    }

    /**
     * Custom hashCode computed on "business key" fields.
     */
    public int hashCode() {
        int result = HashCodeUtil.SEED;
        result = HashCodeUtil.hash(result, getRoleName());
        return result;
    }

}
