/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.persistence.pv;

import gov.anl.aps.irmis.persistence.HashCodeUtil;
import java.io.Serializable;
import java.util.Date;

/**
 * IRMIS business object that represents a single EPICS IOC attribute.
 * This class is mapped via hibernate almost one-to-one with IRMIS ioc_attr table.
 */
public class IOCAttribute implements Serializable, Comparable {

    private Long id;
    private String attributeValue;
    private IOC ioc;
    private IOCAttributeType iocAttributeType;

    /**
     * Constructor
     */
    public IOCAttribute() {
    }

    /**
     * Get primary key.
     */
    public Long getId() {
        return this.id;
    }

    /**
     * Primary key. Not typically set explicitly by application code.
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * Get IOC associated with this attribute.
     */
    public IOC getIoc() {
        return this.ioc;
    }
    /**
     * Set IOC associated with this attribute.
     */
    public void setIoc(IOC value) {
        this.ioc = value;
    }

    /**
     * Get type of this attribute.
     */
    public IOCAttributeType getAttributeType() {
        return this.iocAttributeType;
    }

    /**
     * Set type of this attribute.
     */
    public void setAttributeType(IOCAttributeType type) {
        this.iocAttributeType = type;
    }

    /**
     * Get the ioc attribute value. 
     */
    public String getAttributeValue() {
        return this.attributeValue;
    }
    /**
     * Set the ioc attribute value. 
     */    
    public void setAttributeValue(String attributeValue) {
        this.attributeValue = attributeValue;
    }

    public String toString() {
        return getId().toString() + ":" + getAttributeValue();
    }

    /**
     * Required to implement Comparable interface. Orders attributes by the
     * attribute type name. Not generally recommended
     * that compareTo uses different comparators than equals method, but
     * should be ok with our expected usage.
     */
    public int compareTo(Object o) {
        IOCAttribute otherAttr = (IOCAttribute)o;
        return this.getAttributeType().getAttributeType()
            .compareTo(otherAttr.getAttributeType().getAttributeType());
    }

    /**
     * Custom equals which compares "business key" equality.
     */
    public boolean equals(Object other) {
        if (this==other) return true;
        if ( !(other instanceof IOCAttribute) ) return false;
        final IOCAttribute castOther = (IOCAttribute) other;
        return this.getIoc() == castOther.getIoc() &&
            this.getAttributeType() == castOther.getAttributeType();
    }

    /**
     * Custom hashCode computed on "business key" fields.
     */
    public int hashCode() {
        int result = HashCodeUtil.SEED;
        result = HashCodeUtil.hash(result,getIoc().getId());
        result = HashCodeUtil.hash(result,getAttributeType().getAttributeType());
        return result;
    }

}
